/**
 * Conversation helper
 *
 * This class is an interface between the server
 * and the conversations widgets
 *
 * @author Pierre HUBERT
 */
#ifndef CONVERSATIONHELPER_H
#define CONVERSATIONHELPER_H

#include <QObject>

#include "../data/newconversationmessage.h"
#include "../data/apirequest.h"

class APIHelper;

class ConversationHelper : public QObject
{
    Q_OBJECT
public:
    explicit ConversationHelper(QObject *parent = nullptr);

    /**
     * Send a message to the server
     *
     * @param message Information about the message to send
     */
    void sendMessage(const NewConversationMessage &message);

signals:

    /**
     * This signal is emitted when we have got the result of a create message
     * attempt
     *
     * @param success TRUE if the operation is a success / FALSE
     */
    void sendMessageCallback(bool success);

public slots:


private slots:

    /**
     * Send message callback
     *
     * @param code The code of the error
     * @param & Server response (useless in this case)
     */
    void sendMessageFinished(int code);

private:

    //Private fields
    APIHelper *mAPIHelper;
};

#endif // CONVERSATIONHELPER_H
